@@ -1,4 +1,4 @@
-#  Copyright © 2020 Ingram Micro Inc. All rights reserved.
+#  Copyright © 2021 Ingram Micro Inc. All rights reserved.
 
 from django.db import models, transaction
 from django.dispatch import Signal
@@ -47,6 +47,10 @@ class MasterSignals:
         if not sender.CQRS_PRODUCE:
             return
 
+        update_fields = kwargs.get('update_fields')
+        if update_fields and ('cqrs_revision' not in update_fields):
+            return
+
         instance = kwargs['instance']
         if not instance.is_sync_instance():
             return
@@ -112,13 +116,16 @@ class MasterSignals:
         """
         :param dj_cqrs.mixins.MasterMixin sender: Class or instance inherited from CQRS MasterMixin.
         """
-        for instance in kwargs['instances']:
-            cls.post_save(sender, instance=instance, using=kwargs['using'])
+        cls._post_bulk(sender, **kwargs)
 
     @classmethod
     def post_bulk_update(cls, sender, **kwargs):
         """
         :param dj_cqrs.mixins.MasterMixin sender: Class or instance inherited from CQRS MasterMixin.
         """
+        cls._post_bulk(sender, **kwargs)
+
+    @classmethod
+    def _post_bulk(cls, sender, **kwargs):
         for instance in kwargs['instances']:
             cls.post_save(sender, instance=instance, using=kwargs['using'])
