@@ -1,4 +1,4 @@
-#  Copyright © 2020 Ingram Micro Inc. All rights reserved.
+#  Copyright © 2021 Ingram Micro Inc. All rights reserved.
 
 from django.conf import settings
 from django.utils.module_loading import import_string
@@ -8,8 +8,7 @@ from dj_cqrs.transport.kombu import KombuTransport
 from dj_cqrs.transport.rabbit_mq import RabbitMQTransport
 
 
-transport_cls_location = getattr(settings, 'CQRS', {}) \
-    .get('transport')
+transport_cls_location = getattr(settings, 'CQRS', {}).get('transport')
 if not transport_cls_location:
     raise AttributeError('CQRS transport is not set.')
 
@@ -23,4 +22,4 @@ except (ImportError, ValueError):
     raise ImportError('Bad CQRS transport class.')
 
 
-__all__ = [BaseTransport, KombuTransport, RabbitMQTransport, current_transport]
+__all__ = ['BaseTransport', 'KombuTransport', 'RabbitMQTransport', current_transport]
